@@ -1,5 +1,10 @@
-/*
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+/******************************************************************************
+ *
+ *  swordstub.cpp -	JNI bindings
+ *
+ * $Id: swordstub.cpp 2894 2013-07-16 04:38:43Z scribe $
+ *
+ * Copyright 2009-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -154,7 +159,7 @@ JNIEXPORT jobjectArray JNICALL Java_org_crosswire_android_sword_SWMgr_getModInfo
 	init();
 
 	int size = 0;
-	for (sword::ModMap::iterator it = mgr->Modules.begin(); it != mgr->Modules.end(); it++) {
+	for (sword::ModMap::iterator it = mgr->Modules.begin(); it != mgr->Modules.end(); ++it) {
 		if ((!(it->second->getConfigEntry("CipherKey"))) || (*(it->second->getConfigEntry("CipherKey"))))
 			size++;
 	}
@@ -172,11 +177,11 @@ SWLog::getSystemLog()->logDebug("getModInfoList returning %d length array\n", si
 	jobjectArray ret = (jobjectArray) env->NewObjectArray(size, clazzModInfo, NULL);
 
 	int i = 0;
-	for (sword::ModMap::iterator it = mgr->Modules.begin(); it != mgr->Modules.end(); it++) {
+	for (sword::ModMap::iterator it = mgr->Modules.begin(); it != mgr->Modules.end(); ++it) {
 		SWModule *module = it->second;
 
 		if ((!(module->getConfigEntry("CipherKey"))) || (*(module->getConfigEntry("CipherKey")))) {
-			SWBuf type = module->Type();
+			SWBuf type = module->getType();
 			SWBuf cat = module->getConfigEntry("Category");
 			SWBuf version = module->getConfigEntry("Version");
 			if (cat.length() > 0) type = cat;
@@ -184,10 +189,10 @@ SWLog::getSystemLog()->logDebug("getModInfoList returning %d length array\n", si
 			jobject modInfo = env->AllocObject(clazzModInfo); 
 
 			jstring val;
-			val = env->NewStringUTF(assureValidUTF8(module->Name()));        env->SetObjectField(modInfo, nameID   , val); env->DeleteLocalRef(val);
-			val = env->NewStringUTF(assureValidUTF8(module->Description())); env->SetObjectField(modInfo, descID   , val); env->DeleteLocalRef(val);
+			val = env->NewStringUTF(assureValidUTF8(module->getName()));        env->SetObjectField(modInfo, nameID   , val); env->DeleteLocalRef(val);
+			val = env->NewStringUTF(assureValidUTF8(module->getDescription())); env->SetObjectField(modInfo, descID   , val); env->DeleteLocalRef(val);
 			val = env->NewStringUTF(assureValidUTF8(type.c_str()));          env->SetObjectField(modInfo, catID    , val); env->DeleteLocalRef(val);
-			val = env->NewStringUTF(assureValidUTF8(module->Lang()));        env->SetObjectField(modInfo, langID   , val); env->DeleteLocalRef(val);
+			val = env->NewStringUTF(assureValidUTF8(module->getLanguage()));        env->SetObjectField(modInfo, langID   , val); env->DeleteLocalRef(val);
 			val = env->NewStringUTF(assureValidUTF8(version.c_str()));       env->SetObjectField(modInfo, versionID, val); env->DeleteLocalRef(val);
 			val = env->NewStringUTF(assureValidUTF8(""));                    env->SetObjectField(modInfo, deltaID  , val); env->DeleteLocalRef(val);
 
@@ -217,14 +222,14 @@ JNIEXPORT jobject JNICALL Java_org_crosswire_android_sword_SWMgr_getModuleByName
      env->ReleaseStringUTFChars(modNameJS, modName);
 
 	if (module) {
-		SWBuf type = module->Type();
+		SWBuf type = module->getType();
 		SWBuf cat = module->getConfigEntry("Category");
 		if (cat.length() > 0) type = cat;
 		jfieldID fieldID;
 		jclass clazzSWModule = env->FindClass("org/crosswire/android/sword/SWModule");
 		retVal = env->AllocObject(clazzSWModule); 
-		fieldID = env->GetFieldID(clazzSWModule, "name", "Ljava/lang/String;"); env->SetObjectField(retVal, fieldID, env->NewStringUTF(assureValidUTF8(module->Name())));
-		fieldID = env->GetFieldID(clazzSWModule, "description", "Ljava/lang/String;"); env->SetObjectField(retVal, fieldID, env->NewStringUTF(assureValidUTF8(module->Description())));
+		fieldID = env->GetFieldID(clazzSWModule, "name", "Ljava/lang/String;"); env->SetObjectField(retVal, fieldID, env->NewStringUTF(assureValidUTF8(module->getName())));
+		fieldID = env->GetFieldID(clazzSWModule, "description", "Ljava/lang/String;"); env->SetObjectField(retVal, fieldID, env->NewStringUTF(assureValidUTF8(module->getDescription())));
 		fieldID = env->GetFieldID(clazzSWModule, "category", "Ljava/lang/String;"); env->SetObjectField(retVal, fieldID, env->NewStringUTF(assureValidUTF8(type.c_str())));
 	}
 	return retVal;
@@ -328,7 +333,7 @@ JNIEXPORT jobjectArray JNICALL Java_org_crosswire_android_sword_SWMgr_getGlobalO
 
 	sword::StringList options = mgr->getGlobalOptions();
 	int count = 0;
-	for (sword::StringList::iterator it = options.begin(); it != options.end(); it++) {
+	for (sword::StringList::iterator it = options.begin(); it != options.end(); ++it) {
 		count++;
 	}
 
@@ -336,7 +341,7 @@ JNIEXPORT jobjectArray JNICALL Java_org_crosswire_android_sword_SWMgr_getGlobalO
 	jobjectArray ret = (jobjectArray) env->NewObjectArray(count, clazzString, NULL);
 
 	count = 0;
-	for (sword::StringList::iterator it = options.begin(); it != options.end(); it++) {
+	for (sword::StringList::iterator it = options.begin(); it != options.end(); ++it) {
 		env->SetObjectArrayElement(ret, count++, env->NewStringUTF(assureValidUTF8(*it)));
 	}
 
@@ -361,14 +366,14 @@ JNIEXPORT jobjectArray JNICALL Java_org_crosswire_android_sword_SWMgr_getGlobalO
      env->ReleaseStringUTFChars(optionJS, option);
 
 	int count = 0;
-	for (sword::StringList::iterator it = options.begin(); it != options.end(); it++) {
+	for (sword::StringList::iterator it = options.begin(); it != options.end(); ++it) {
 		count++;
 	}
 	jclass clazzString = env->FindClass("java/lang/String");
 	jobjectArray ret = (jobjectArray) env->NewObjectArray(count, clazzString, NULL);
 
 	count = 0;
-	for (sword::StringList::iterator it = options.begin(); it != options.end(); it++) {
+	for (sword::StringList::iterator it = options.begin(); it != options.end(); ++it) {
 		env->SetObjectArrayElement(ret, count++, env->NewStringUTF(assureValidUTF8(*it)));
 	}
 
@@ -422,7 +427,7 @@ JNIEXPORT jobjectArray JNICALL Java_org_crosswire_android_sword_SWMgr_getAvailab
 
 	sword::StringList localeNames = LocaleMgr::getSystemLocaleMgr()->getAvailableLocales();
 	int count = 0;
-	for (sword::StringList::iterator it = localeNames.begin(); it != localeNames.end(); it++) {
+	for (sword::StringList::iterator it = localeNames.begin(); it != localeNames.end(); ++it) {
 		count++;
 	}
 
@@ -430,7 +435,7 @@ JNIEXPORT jobjectArray JNICALL Java_org_crosswire_android_sword_SWMgr_getAvailab
 	jobjectArray ret = (jobjectArray) env->NewObjectArray(count, clazzString, NULL);
 
 	count = 0;
-	for (sword::StringList::iterator it = localeNames.begin(); it != localeNames.end(); it++) {
+	for (sword::StringList::iterator it = localeNames.begin(); it != localeNames.end(); ++it) {
 		env->SetObjectArrayElement(ret, count++, env->NewStringUTF(assureValidUTF8(*it)));
 	}
 	return ret;
@@ -499,7 +504,7 @@ JNIEXPORT void JNICALL Java_org_crosswire_android_sword_SWModule_setKeyText
 
 	if (module) {
 		const char *keyText = env->GetStringUTFChars(keyTextJS, NULL);
-SWLog::getSystemLog()->logDebug("setKeyText(%s, %s)", module->Name(), keyText);
+SWLog::getSystemLog()->logDebug("setKeyText(%s, %s)", module->getName(), keyText);
 		sword::SWKey *key = module->getKey();
 		sword::VerseKey *vkey = SWDYNAMIC_CAST(VerseKey, key);
 		if (vkey && (*keyText=='+' ||*keyText=='-')) {
@@ -515,7 +520,7 @@ SWLog::getSystemLog()->logDebug("setKeyText(%s, %s)", module->Name(), keyText);
 			}
 		}
 
-		module->KeyText(keyText);
+		module->setKey(keyText);
 		env->ReleaseStringUTFChars(keyTextJS, keyText);
 	}
 }
@@ -555,7 +560,7 @@ JNIEXPORT jstring JNICALL Java_org_crosswire_android_sword_SWModule_getRenderTex
 
 	jstring retVal = 0;
 	if (module) {
-		retVal = env->NewStringUTF(assureValidUTF8(module->RenderText()));
+		retVal = env->NewStringUTF(assureValidUTF8(module->renderText()));
 	}
 	return retVal;
 }
@@ -591,7 +596,7 @@ JNIEXPORT jchar JNICALL Java_org_crosswire_android_sword_SWModule_error
 
 	SWModule *module = getModule(env, me);
 	
-	return (module) ? module->Error() : -99;
+	return (module) ? module->popError() : -99;
 }
 
 
@@ -633,7 +638,7 @@ JNIEXPORT jobjectArray JNICALL Java_org_crosswire_android_sword_SWModule_getEntr
 
 	if (module) {
 
-		module->RenderText();	// force parse
+		module->renderText();	// force parse
 		vector<SWBuf> results;
 
 		sword::AttributeTypeList &entryAttribs = module->getEntryAttributes();
@@ -645,35 +650,35 @@ JNIEXPORT jobjectArray JNICALL Java_org_crosswire_android_sword_SWModule_getEntr
 			i1Start = entryAttribs.find(level1);
 			i1End = i1Start;
 			if (i1End != entryAttribs.end())
-				i1End++;
+				++i1End;
 		}
 		else {
 			i1Start = entryAttribs.begin();
 			i1End   = entryAttribs.end();
 		}
-		for (;i1Start != i1End; i1Start++) {
+		for (;i1Start != i1End; ++i1Start) {
 			if ((level2) && (*level2)) {
 				i2Start = i1Start->second.find(level2);
 				i2End = i2Start;
 				if (i2End != i1Start->second.end())
-					i2End++;
+					++i2End;
 			}
 			else {
 				i2Start = i1Start->second.begin();
 				i2End   = i1Start->second.end();
 			}
-			for (;i2Start != i2End; i2Start++) {
+			for (;i2Start != i2End; ++i2Start) {
 				if ((level3) && (*level3)) {
 					i3Start = i2Start->second.find(level3);
 					i3End = i3Start;
 					if (i3End != i2Start->second.end())
-						i3End++;
+						++i3End;
 				}
 				else {
 					i3Start = i2Start->second.begin();
 					i3End   = i2Start->second.end();
 				}
-				for (;i3Start != i3End; i3Start++) {
+				for (;i3Start != i3End; ++i3Start) {
 					results.push_back(i3Start->second);
 				}
 				if (i3Start != i3End)
@@ -689,7 +694,7 @@ SWLog::getSystemLog()->logDebug("getEntryAttributes: size returned: %d", results
 
 		for (int i = 0; i < results.size(); i++) {
 			if (filtered) {
-				env->SetObjectArrayElement(ret, i, env->NewStringUTF(assureValidUTF8(module->RenderText(results[i].c_str()))));
+				env->SetObjectArrayElement(ret, i, env->NewStringUTF(assureValidUTF8(module->renderText(results[i].c_str()))));
 			}
 			else {
 				env->SetObjectArrayElement(ret, i, env->NewStringUTF(assureValidUTF8(results[i].c_str())));
@@ -726,15 +731,15 @@ JNIEXPORT jobjectArray JNICALL Java_org_crosswire_android_sword_SWModule_parseKe
 		sword::VerseKey *parser = SWDYNAMIC_CAST(VerseKey, k);
 		if (parser) {
 			sword::ListKey result;
-			result = parser->ParseVerseList(keyListText, *parser, true);
+			result = parser->parseVerseList(keyListText, *parser, true);
 			int count = 0;
-			for (result = sword::TOP; !result.Error(); result++) {
+			for (result = sword::TOP; !result.popError(); result++) {
 				count++;
 			}
 			ret = (jobjectArray) env->NewObjectArray(count, clazzString, NULL);
 
 			count = 0;
-			for (result = sword::TOP; !result.Error(); result++) {
+			for (result = sword::TOP; !result.popError(); result++) {
 				env->SetObjectArrayElement(ret, count++, env->NewStringUTF(assureValidUTF8((const char *)result)));
 			}
 		}
@@ -947,7 +952,7 @@ JNIEXPORT jstring JNICALL Java_org_crosswire_android_sword_SWModule_getStripText
 	SWModule *module = getModule(env, me);
 
 	if (module) {
-		retVal = module->StripText();
+		retVal = module->stripText();
 	}
 
 	return env->NewStringUTF(assureValidUTF8(retVal));
@@ -1117,7 +1122,7 @@ JNIEXPORT jobjectArray JNICALL Java_org_crosswire_android_sword_SWModule_search
 
 	init(); 
 
-	const int MAX_RETURN_COUNT = 200;
+	const int MAX_RETURN_COUNT = 999999;
 
 	const char *expression = env->GetStringUTFChars(expressionJS, NULL);
 	const char *scope = env->GetStringUTFChars(scopeJS, NULL);
@@ -1134,21 +1139,21 @@ JNIEXPORT jobjectArray JNICALL Java_org_crosswire_android_sword_SWModule_search
 		sword::ListKey result;
 
 		if ((scope) && (strlen(scope)) > 0) {
-			sword::SWKey *p = module->CreateKey();
+			sword::SWKey *p = module->createKey();
 			sword::VerseKey *parser = SWDYNAMIC_CAST(VerseKey, p);
 			if (!parser) {
 				delete p;
 				parser = new VerseKey();
 			}
 			*parser = module->getKeyText();
-			lscope = parser->ParseVerseList(scope, *parser, true);
+			lscope = parser->parseVerseList(scope, *parser, true);
 			result = module->search(expression, srchType, flags, &lscope, 0, &percentUpdate, &peeuuu);
 			delete parser;
 		}
 		else	result = module->search(expression, srchType, flags, 0, 0, &percentUpdate, &peeuuu);
 
 		int count = 0;
-		for (result = sword::TOP; !result.Error(); result++) count++;
+		for (result = sword::TOP; !result.popError(); result++) count++;
 
 		if (count > MAX_RETURN_COUNT) count = MAX_RETURN_COUNT;
 
@@ -1160,17 +1165,25 @@ JNIEXPORT jobjectArray JNICALL Java_org_crosswire_android_sword_SWModule_search
 			result.sort();
 
 		int i = 0;
-		for (result = sword::TOP; !result.Error(); result++) {
+		jstring modName = env->NewStringUTF(assureValidUTF8(module->getName()));
+		jfieldID fieldIDModName = env->GetFieldID(clazzSearchHit, "modName", "Ljava/lang/String;");
+		jfieldID fieldIDKey     = env->GetFieldID(clazzSearchHit, "key"    , "Ljava/lang/String;");
+		jfieldID fieldIDScore   = env->GetFieldID(clazzSearchHit, "score"  , "J");
+		for (result = sword::TOP; !result.popError(); result++) {
 			jfieldID fieldID;
 			jobject searchHit = env->AllocObject(clazzSearchHit); 
 
-			fieldID = env->GetFieldID(clazzSearchHit, "modName", "Ljava/lang/String;"); env->SetObjectField(searchHit, fieldID, env->NewStringUTF(assureValidUTF8(module->Name())));
-			fieldID = env->GetFieldID(clazzSearchHit, "key", "Ljava/lang/String;"); env->SetObjectField(searchHit, fieldID, env->NewStringUTF(assureValidUTF8((const char *)result)));
-			fieldID = env->GetFieldID(clazzSearchHit, "score", "J"); env->SetLongField(searchHit, fieldID, (long)result.getElement()->userData);
+			env->SetObjectField(searchHit, fieldIDModName, modName);
+			jstring key = env->NewStringUTF(assureValidUTF8((const char *)result));
+			env->SetObjectField(searchHit, fieldIDKey, key);
+			env->DeleteLocalRef(key);
+			env->SetLongField(searchHit, fieldIDScore, (long)result.getElement()->userData);
 
 			env->SetObjectArrayElement(ret, i++, searchHit);
-			if (i > MAX_RETURN_COUNT) break;
+			env->DeleteLocalRef(searchHit);
+			if (i >= MAX_RETURN_COUNT) break;
 		}
+		env->DeleteLocalRef(modName);
 	}
 
 	env->ReleaseStringUTFChars(scopeJS, scope);
@@ -1232,7 +1245,7 @@ SWLog::getSystemLog()->logDebug("uninstallModule %s\n", modName);
 		return -2;
 	}
 	module = it->second;
-	installMgr->removeModule(mgr, module->Name());
+	installMgr->removeModule(mgr, module->getName());
 
 	env->ReleaseStringUTFChars(modNameJS, modName);
 
@@ -1254,12 +1267,12 @@ JNIEXPORT jobjectArray JNICALL Java_org_crosswire_android_sword_InstallMgr_getRe
 	jobjectArray ret;
 
 	int count = 0;
-	for (InstallSourceMap::iterator it = installMgr->sources.begin(); it != installMgr->sources.end(); it++) {
+	for (InstallSourceMap::iterator it = installMgr->sources.begin(); it != installMgr->sources.end(); ++it) {
 		count++;
 	}
 	ret = (jobjectArray) env->NewObjectArray(count, clazzString, NULL);
 	count = 0;
-	for (InstallSourceMap::iterator it = installMgr->sources.begin(); it != installMgr->sources.end(); it++) {
+	for (InstallSourceMap::iterator it = installMgr->sources.begin(); it != installMgr->sources.end(); ++it) {
 		env->SetObjectArrayElement(ret, count++, env->NewStringUTF(assureValidUTF8(it->second->caption.c_str())));
 	}
 
@@ -1323,7 +1336,7 @@ SWLog::getSystemLog()->logDebug("found source: %s\n", sourceName);
 	map<SWModule *, int> modStats = installMgr->getModuleStatus(*mgr, *source->second->getMgr());
 
 	int size = 0;
-	for (map<SWModule *, int>::iterator it = modStats.begin(); it != modStats.end(); it++) {
+	for (map<SWModule *, int>::iterator it = modStats.begin(); it != modStats.end(); ++it) {
 		size++;
 	}
 
@@ -1331,7 +1344,7 @@ SWLog::getSystemLog()->logDebug("remoteListModules returning %d length array\n",
 	jobjectArray ret = (jobjectArray) env->NewObjectArray(size, clazzModInfo, NULL);
 
 	int i = 0;
-	for (map<SWModule *, int>::iterator it = modStats.begin(); it != modStats.end(); it++) {
+	for (map<SWModule *, int>::iterator it = modStats.begin(); it != modStats.end(); ++it) {
 		SWModule *module = it->first;
 		int status = it->second;
 
@@ -1341,16 +1354,16 @@ SWLog::getSystemLog()->logDebug("remoteListModules returning %d length array\n",
 		if (it->second & InstallMgr::MODSTAT_OLDER) statusString = "-";
 		if (it->second & InstallMgr::MODSTAT_UPDATED) statusString = "+";
 
-		SWBuf type = module->Type();
+		SWBuf type = module->getType();
 		SWBuf cat = module->getConfigEntry("Category");
 		if (cat.length() > 0) type = cat;
 		jobject modInfo = env->AllocObject(clazzModInfo); 
 
 		jstring val;
-		val = env->NewStringUTF(assureValidUTF8(module->Name()));        env->SetObjectField(modInfo, nameID   , val); env->DeleteLocalRef(val);
-		val = env->NewStringUTF(assureValidUTF8(module->Description())); env->SetObjectField(modInfo, descID   , val); env->DeleteLocalRef(val);
+		val = env->NewStringUTF(assureValidUTF8(module->getName()));        env->SetObjectField(modInfo, nameID   , val); env->DeleteLocalRef(val);
+		val = env->NewStringUTF(assureValidUTF8(module->getDescription())); env->SetObjectField(modInfo, descID   , val); env->DeleteLocalRef(val);
 		val = env->NewStringUTF(assureValidUTF8(type.c_str()));          env->SetObjectField(modInfo, catID    , val); env->DeleteLocalRef(val);
-		val = env->NewStringUTF(assureValidUTF8(module->Lang()));        env->SetObjectField(modInfo, langID   , val); env->DeleteLocalRef(val);
+		val = env->NewStringUTF(assureValidUTF8(module->getLanguage()));        env->SetObjectField(modInfo, langID   , val); env->DeleteLocalRef(val);
 		val = env->NewStringUTF(assureValidUTF8(version.c_str()));       env->SetObjectField(modInfo, versionID, val); env->DeleteLocalRef(val);
 		val = env->NewStringUTF(assureValidUTF8(statusString.c_str()));  env->SetObjectField(modInfo, deltaID  , val); env->DeleteLocalRef(val);
 
@@ -1399,7 +1412,7 @@ SWLog::getSystemLog()->logDebug("remoteInstallModule: modName: %s\n", modName);
 
 	module = it->second;
 
-	int error = installMgr->installModule(mgr, 0, module->Name(), is);
+	int error = installMgr->installModule(mgr, 0, module->getName(), is);
 
 	return error;
 }
@@ -1434,14 +1447,14 @@ SWLog::getSystemLog()->logDebug("Couldn't find remote source [%s]\n", sourceName
      env->ReleaseStringUTFChars(modNameJS, modName);
 
 	if (module) {
-		SWBuf type = module->Type();
+		SWBuf type = module->getType();
 		SWBuf cat = module->getConfigEntry("Category");
 		if (cat.length() > 0) type = cat;
 		jfieldID fieldID;
 		jclass clazzSWModule = env->FindClass("org/crosswire/android/sword/SWModule");
 		retVal = env->AllocObject(clazzSWModule); 
-		fieldID = env->GetFieldID(clazzSWModule, "name", "Ljava/lang/String;"); env->SetObjectField(retVal, fieldID, env->NewStringUTF(assureValidUTF8(module->Name())));
-		fieldID = env->GetFieldID(clazzSWModule, "description", "Ljava/lang/String;"); env->SetObjectField(retVal, fieldID, env->NewStringUTF(assureValidUTF8(module->Description())));
+		fieldID = env->GetFieldID(clazzSWModule, "name", "Ljava/lang/String;"); env->SetObjectField(retVal, fieldID, env->NewStringUTF(assureValidUTF8(module->getName())));
+		fieldID = env->GetFieldID(clazzSWModule, "description", "Ljava/lang/String;"); env->SetObjectField(retVal, fieldID, env->NewStringUTF(assureValidUTF8(module->getDescription())));
 		fieldID = env->GetFieldID(clazzSWModule, "category", "Ljava/lang/String;"); env->SetObjectField(retVal, fieldID, env->NewStringUTF(assureValidUTF8(type.c_str())));
 		fieldID = env->GetFieldID(clazzSWModule, "remoteSourceName", "Ljava/lang/String;"); env->SetObjectField(retVal, fieldID, sourceNameJS);
 	}
