@@ -6,7 +6,7 @@
 //  Copyright 2010 Software by MABE. All rights reserved.
 //
 
-#import <Cocoa/Cocoa.h>
+#import <Foundation/Foundation.h>
 
 @interface SwordLocaleManager : NSObject {
 }
@@ -15,8 +15,14 @@
 
 /**
  Initializes the global locale system.
- Any created instance that needs localozed information will use it.
+ Any created instance that needs localized information will use it.
  */
 - (void)initLocale;
 
+/**
+ Initializes global locale system.
+ Loads the locale (locale.d) folder from the specified path.
+ */
+- (void)initLocaleWithLocaledPath:(NSString *)aPath;
+
 @end
