@@ -1,9 +1,10 @@
 /******************************************************************************
- *  swcomprs.cpp   - code for class 'SWCompress'- a driver class that provides
- *				compression utilities.
  *
+ *  swcomprs.cpp - 	a driver class that provides compression utilities
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: swcomprs.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 1996-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
