@@ -2,7 +2,7 @@
  *
  *  osisrtf.cpp -	OSIS to RTF filter
  *
- * $Id: osisrtf.cpp 2994 2013-12-28 05:54:40Z greg.hellings $ *
+ * $Id: osisrtf.cpp 3005 2014-01-09 04:06:11Z greg.hellings $ *
  *
  * Copyright 2003-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -326,7 +326,7 @@ bool OSISRTF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 		}
 
 		// <milestone type="line"/> or <lb.../>
-		else if ((!strcmp(tag.getName(), "lb") && (strcmp(tag.getAttribute("type"), "x-optional"))) || ((!strcmp(tag.getName(), "milestone")) && (tag.getAttribute("type")) && (!strcmp(tag.getAttribute("type"), "line")))) {
+		else if ((!strcmp(tag.getName(), "lb") && (!tag.getAttribute("type") || strcmp(tag.getAttribute("type"), "x-optional"))) || ((!strcmp(tag.getName(), "milestone")) && (tag.getAttribute("type")) && (!strcmp(tag.getAttribute("type"), "line")))) {
 			outText("{\\par}", buf, u);
 			userData->supressAdjacentWhitespace = true;
 		}
