@@ -1,5 +1,10 @@
-/*
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+/******************************************************************************
+ *
+ *  diathekemgr.cpp -	DiathekeMgr
+ *
+ * $Id: diathekemgr.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -79,10 +84,10 @@ void DiathekeMgr::AddRenderFilters(SWModule *module, ConfigEntMap &section)
 
 #ifdef _ICU_
 	if (shape) {
-		module->AddRenderFilter(arshaping);
+		module->addRenderFilter(arshaping);
 	}
 	if (bidi && rtl) {
-		module->AddRenderFilter(bidireorder);
+		module->addRenderFilter(bidireorder);
 	}
 #endif
 	SWMgr::AddRenderFilters(module, section);
@@ -103,7 +108,7 @@ void DiathekeMgr::AddGlobalOptions (SWModule * module, ConfigEntMap & section,
 
         SWMgr::AddGlobalOptions(module, section, start, end);
 #ifdef _ICU_
-        module->AddOptionFilter(transliterator);
+        module->addOptionFilter(transliterator);
 #endif
 };
 
